@@ -793,7 +793,7 @@ class PublisherThread(Thread):
                                    routing_key=self.server_id + "_server_routing_key",
                                    serializer=self.serializer)
                 except Exception:
-                    logger.exeption('Exception: During connection a broken AMQP Connection')
+                    logger.exception('Exception: During connection a broken AMQP Connection')
     
 #===========================================================================
 
